@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
@@ -12,8 +12,8 @@ class QuickTestConfiguration : public DebuggableTestConfiguration
 {
 public:
     explicit QuickTestConfiguration(ITestFramework *framework);
-    TestOutputReader *outputReader(const QFutureInterface<TestResultPtr> &fi,
-                                   Utils::QtcProcess *app) const override;
+    TestOutputReader *createOutputReader(const QFutureInterface<TestResult> &fi,
+                                         Utils::QtcProcess *app) const override;
     QStringList argumentsForTestRunner(QStringList *omitted = nullptr) const override;
     Utils::Environment filteredEnvironment(const Utils::Environment &original) const override;
 };
